# Interactive Corpus Analysis Tool

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PyPI version](https://badge.fury.io/py/icat-iml.svg)](https://badge.fury.io/py/icat-iml)
[![tests](https://github.com/ORNL/icat/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/ORNL/icat/actions/workflows/tests.yml)

The Interactive Corpus Analysis Tool (ICAT) is a program that can be used to explore textual corpora and train intelligent filters to identify specific documents of interest.


## Installation

```
pip install icat-iml
```
